.. oHySEM documentation master file, created by Erik Alvarez

Research Projects
=================

The model has being used in this research project:

- Smart Charging ALignment for Europe  (SCALE), a three-year project (2022-2025) co-funded by the new **European Union’s Horizon 2020 research and innovation programme** under grant agreement No 101056874 with a budget of around 10 million EUR. It aims to advance smart charging infrastructure and facilitate the mass deployment of electric vehicles.
  `A. Ramos <https://www.iit.comillas.edu/people/aramos>`_, `J.M. Latorre <https://www.iit.comillas.edu/people/jesuslc>`_, `P. Sanchez <https://www.iit.comillas.edu/people/psanchez>`_, `E.F. Álvarez <https://www.iit.comillas.edu/people/ealvarezq>`_, `P. Rodilla <https://www.iit.comillas.edu/people/prodilla>`_, `P. Mastropietro <https://www.iit.comillas.edu/people/pmastropietro>`_, `C. Batlle <https://www.iit.comillas.edu/people/batlle>`_, `A. Bello <https://www.iit.comillas.edu/people/abello>`_, `D.M. Navarrete <https://www.iit.comillas.edu/people/dmnavarrete>`_

.. image:: /../img/ColabPP.png
   :scale: 30%
   :align: center
